package dev.fyloz.colorrecipesexplorer.repository

import dev.fyloz.colorrecipesexplorer.model.MaterialType
import org.springframework.data.jpa.repository.Query
import org.springframework.stereotype.Repository

@Repository
interface MaterialTypeRepository : NamedJpaRepository<MaterialType> {
    /** Checks if a material type exists with the given [prefix]. */
    fun existsByPrefix(prefix: String): Boolean

    /** Gets all material types which are not system types. */
    fun findAllBySystemTypeIs(value: Boolean): Collection<MaterialType>

    /** Gets the material type with the given [prefix]. */
    fun findByPrefix(prefix: String): MaterialType?

    @Query(
      """
        select case when(count(m.id) > 0) then false else true end
        from MaterialType t
        left join Material m on t.id = m.materialType.id
        where t.id = :id
    """
    )
    fun canBeDeleted(id: Long): Boolean
}
