package dev.fyloz.colorrecipesexplorer.rest

import dev.fyloz.colorrecipesexplorer.model.MaterialQuantityDto
import dev.fyloz.colorrecipesexplorer.model.MixDeductDto
import dev.fyloz.colorrecipesexplorer.service.InventoryService
import org.springframework.http.ResponseEntity
import org.springframework.security.access.prepost.PreAuthorize
import org.springframework.web.bind.annotation.PutMapping
import org.springframework.web.bind.annotation.RequestBody
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RestController

private const val INVENTORY_CONTROLLER_PATH = "api/inventory"

@RestController
@RequestMapping(INVENTORY_CONTROLLER_PATH)
class InventoryController(
  private val inventoryService: InventoryService
) {
    @PutMapping("add")
    @PreAuthorize("hasAuthority('ADD_TO_INVENTORY')")
    fun add(@RequestBody quantities: Collection<MaterialQuantityDto>): ResponseEntity<Collection<MaterialQuantityDto>> {
        return ResponseEntity.ok(inventoryService.add(quantities))
    }

    @PutMapping("deduct")
    @PreAuthorize("hasAuthority('DEDUCT_FROM_INVENTORY')")
    fun deduct(@RequestBody quantities: Collection<MaterialQuantityDto>) =
      ok(inventoryService.deduct(quantities))

    @PutMapping("deduct/mix")
    @PreAuthorize("hasAuthority('DEDUCT_FROM_INVENTORY')")
    fun deduct(@RequestBody mixRatio: MixDeductDto) =
      ok(inventoryService.deductMix(mixRatio))
}
